==> vtk6-6.3.0-5-armv6h.pkg.tar.xz: vtk/vtkEllipticalButtonSource.java <==
// java wrapper for vtkEllipticalButtonSource object
//

package vtk;
import vtk.*;

public class vtkEllipticalButtonSource extends vtkButtonSource
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetWidth_2(double id0);
  public void SetWidth(double id0)
    { SetWidth_2(id0); }

  private native double GetWidthMinValue_3();
  public double GetWidthMinValue()
    { return GetWidthMinValue_3(); }

  private native double GetWidthMaxValue_4();
  public double GetWidthMaxValue()
    { return GetWidthMaxValue_4(); }

  private native double GetWidth_5();
  public double GetWidth()
    { return GetWidth_5(); }

  private native void SetHeight_6(double id0);
  public void SetHeight(double id0)
    { SetHeight_6(id0); }

  private native double GetHeightMinValue_7();
  public double GetHeightMinValue()
    { return GetHeightMinValue_7(); }

  private native double GetHeightMaxValue_8();
  public double GetHeightMaxValue()
    { return GetHeightMaxValue_8(); }

  private native double GetHeight_9();
  public double GetHeight()
    { return GetHeight_9(); }

  private native void SetDepth_10(double id0);
  public void SetDepth(double id0)
    { SetDepth_10(id0); }

  private native double GetDepthMinValue_11();
  public double GetDepthMinValue()
    { return GetDepthMinValue_11(); }

  private native double GetDepthMaxValue_12();
  public double GetDepthMaxValue()
    { return GetDepthMaxValue_12(); }

  private native double GetDepth_13();
  public double GetDepth()
    { return GetDepth_13(); }

  private native void SetCircumferentialResolution_14(int id0);
  public void SetCircumferentialResolution(int id0)
    { SetCircumferentialResolution_14(id0); }

  private native int GetCircumferentialResolutionMinValue_15();
  public int GetCircumferentialResolutionMinValue()
    { return GetCircumferentialResolutionMinValue_15(); }

  private native int GetCircumferentialResolutionMaxValue_16();
  public int GetCircumferentialResolutionMaxValue()
    { return GetCircumferentialResolutionMaxValue_16(); }

  private native int GetCircumferentialResolution_17();
  public int GetCircumferentialResolution()
    { return GetCircumferentialResolution_17(); }

  private native void SetTextureResolution_18(int id0);
  public void SetTextureResolution(int id0)
    { SetTextureResolution_18(id0); }

  private native int GetTextureResolutionMinValue_19();
  public int GetTextureResolutionMinValue()
    { return GetTextureResolutionMinValue_19(); }

  private native int GetTextureResolutionMaxValue_20();
  public int GetTextureResolutionMaxValue()
    { return GetTextureResolutionMaxValue_20(); }

  private native int GetTextureResolution_21();
  public int GetTextureResolution()
    { return GetTextureResolution_21(); }

  private native void SetShoulderResolution_22(int id0);
  public void SetShoulderResolution(int id0)
    { SetShoulderResolution_22(id0); }

  private native int GetShoulderResolutionMinValue_23();
  public int GetShoulderResolutionMinValue()
    { return GetShoulderResolutionMinValue_23(); }

  private native int GetShoulderResolutionMaxValue_24();
  public int GetShoulderResolutionMaxValue()
    { return GetShoulderResolutionMaxValue_24(); }

  private native int GetShoulderResolution_25();
  public int GetShoulderResolution()
    { return GetShoulderResolution_25(); }

  private native void SetRadialRatio_26(double id0);
  public void SetRadialRatio(double id0)
    { SetRadialRatio_26(id0); }

  private native double GetRadialRatioMinValue_27();
  public double GetRadialRatioMinValue()
    { return GetRadialRatioMinValue_27(); }

  private native double GetRadialRatioMaxValue_28();
  public double GetRadialRatioMaxValue()
    { return GetRadialRatioMaxValue_28(); }

  private native double GetRadialRatio_29();
  public double GetRadialRatio()
    { return GetRadialRatio_29(); }

  private native void SetOutputPointsPrecision_30(int id0);
  public void SetOutputPointsPrecision(int id0)
    { SetOutputPointsPrecision_30(id0); }

  private native int GetOutputPointsPrecision_31();
  public int GetOutputPointsPrecision()
    { return GetOutputPointsPrecision_31(); }

  public vtkEllipticalButtonSource() { super(); }

  public vtkEllipticalButtonSource(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-14-armv6h.pkg.tar.xz: vtk/vtkEllipticalButtonSource.java <==
// java wrapper for vtkEllipticalButtonSource object
//

package vtk;
import vtk.*;

public class vtkEllipticalButtonSource extends vtkButtonSource
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetWidth_2(double id0);
  public void SetWidth(double id0)
    { SetWidth_2(id0); }

  private native double GetWidthMinValue_3();
  public double GetWidthMinValue()
    { return GetWidthMinValue_3(); }

  private native double GetWidthMaxValue_4();
  public double GetWidthMaxValue()
    { return GetWidthMaxValue_4(); }

  private native double GetWidth_5();
  public double GetWidth()
    { return GetWidth_5(); }

  private native void SetHeight_6(double id0);
  public void SetHeight(double id0)
    { SetHeight_6(id0); }

  private native double GetHeightMinValue_7();
  public double GetHeightMinValue()
    { return GetHeightMinValue_7(); }

  private native double GetHeightMaxValue_8();
  public double GetHeightMaxValue()
    { return GetHeightMaxValue_8(); }

  private native double GetHeight_9();
  public double GetHeight()
    { return GetHeight_9(); }

  private native void SetDepth_10(double id0);
  public void SetDepth(double id0)
    { SetDepth_10(id0); }

  private native double GetDepthMinValue_11();
  public double GetDepthMinValue()
    { return GetDepthMinValue_11(); }

  private native double GetDepthMaxValue_12();
  public double GetDepthMaxValue()
    { return GetDepthMaxValue_12(); }

  private native double GetDepth_13();
  public double GetDepth()
    { return GetDepth_13(); }

  private native void SetCircumferentialResolution_14(int id0);
  public void SetCircumferentialResolution(int id0)
    { SetCircumferentialResolution_14(id0); }

  private native int GetCircumferentialResolutionMinValue_15();
  public int GetCircumferentialResolutionMinValue()
    { return GetCircumferentialResolutionMinValue_15(); }

  private native int GetCircumferentialResolutionMaxValue_16();
  public int GetCircumferentialResolutionMaxValue()
    { return GetCircumferentialResolutionMaxValue_16(); }

  private native int GetCircumferentialResolution_17();
  public int GetCircumferentialResolution()
    { return GetCircumferentialResolution_17(); }

  private native void SetTextureResolution_18(int id0);
  public void SetTextureResolution(int id0)
    { SetTextureResolution_18(id0); }

  private native int GetTextureResolutionMinValue_19();
  public int GetTextureResolutionMinValue()
    { return GetTextureResolutionMinValue_19(); }

  private native int GetTextureResolutionMaxValue_20();
  public int GetTextureResolutionMaxValue()
    { return GetTextureResolutionMaxValue_20(); }

  private native int GetTextureResolution_21();
  public int GetTextureResolution()
    { return GetTextureResolution_21(); }

  private native void SetShoulderResolution_22(int id0);
  public void SetShoulderResolution(int id0)
    { SetShoulderResolution_22(id0); }

  private native int GetShoulderResolutionMinValue_23();
  public int GetShoulderResolutionMinValue()
    { return GetShoulderResolutionMinValue_23(); }

  private native int GetShoulderResolutionMaxValue_24();
  public int GetShoulderResolutionMaxValue()
    { return GetShoulderResolutionMaxValue_24(); }

  private native int GetShoulderResolution_25();
  public int GetShoulderResolution()
    { return GetShoulderResolution_25(); }

  private native void SetRadialRatio_26(double id0);
  public void SetRadialRatio(double id0)
    { SetRadialRatio_26(id0); }

  private native double GetRadialRatioMinValue_27();
  public double GetRadialRatioMinValue()
    { return GetRadialRatioMinValue_27(); }

  private native double GetRadialRatioMaxValue_28();
  public double GetRadialRatioMaxValue()
    { return GetRadialRatioMaxValue_28(); }

  private native double GetRadialRatio_29();
  public double GetRadialRatio()
    { return GetRadialRatio_29(); }

  private native void SetOutputPointsPrecision_30(int id0);
  public void SetOutputPointsPrecision(int id0)
    { SetOutputPointsPrecision_30(id0); }

  private native int GetOutputPointsPrecision_31();
  public int GetOutputPointsPrecision()
    { return GetOutputPointsPrecision_31(); }

  public vtkEllipticalButtonSource() { super(); }

  public vtkEllipticalButtonSource(long id) { super(id); }
  public native long   VTKInit();

}
